.. include:: readme.rst

.. toctree::
   :caption: Getting Started
   :maxdepth: 2

   Overview <readme>

.. toctree::
   :caption: Advanced Usage
   :maxdepth: 2

   database
   cli
   rest
   add_method

.. toctree::
   :caption: Resources

   API Reference <api/atm>
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
